#!/usr/bin/env bash
#
# Entrypoint for the xle Docker image.
# 
# XLE needs a sentence and a grammar. You can use either of the following two ways to provide them to an xle container:
# 1) Mount grammar as /grammar.lfg, pass sentence as first and only command line argument ($1)
# 2) Pass a base64-encoded JSON containing the attributes "sentence" and "grammar" as first and only command line argument ($1) 

if [[ ! -f /grammar.lfg ]]
then
    JSON=$(echo $1 | base64 -d)
    SENTENCE=$(echo $JSON | jq -r .sentence)
    echo $JSON | jq -r .grammar > /grammar.lfg
else
    SENTENCE=$1
fi

# Write xlerc containing instructions to parse
echo "create-parser /grammar.lfg" > xlerc
echo "packed-xml-fs { $SENTENCE } packed-parses.xml" >> xlerc
echo "exit" >> xlerc

# Start XLE (under the X server), this will automatically load xlerc, let it complete the parse and end
# Save the messages of xle to xle_messages.txt
xvfb-run xle > xle_messages.txt 2> /dev/null


if [[ -f packed-parses.xml ]]
then
    # Print parse file to stdout and exit with success
    cat packed-parses.xml
    exit 0
else
    # Print xle output to stderr and fail
    cat xle_messages.txt >&2
    exit 42
fi
